==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/dayu/v20180709/models/DescribeDDoSAttackSourceResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dayu.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDDoSAttackSourceResponse extends AbstractModel{

    /**
    * 总攻击源条数
    */
    @SerializedName("Total")
    @Expose
    private Long Total;

    /**
    * 攻击源列表
    */
    @SerializedName("AttackSourceList")
    @Expose
    private DDoSAttackSourceRecord [] AttackSourceList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 总攻击源条数 
     * @return Total 总攻击源条数
     */
    public Long getTotal() {
        return this.Total;
    }

    /**
     * Set 总攻击源条数
     * @param Total 总攻击源条数
     */
    public void setTotal(Long Total) {
        this.Total = Total;
    }

    /**
     * Get 攻击源列表 
     * @return AttackSourceList 攻击源列表
     */
    public DDoSAttackSourceRecord [] getAttackSourceList() {
        return this.AttackSourceList;
    }

    /**
     * Set 攻击源列表
     * @param AttackSourceList 攻击源列表
     */
    public void setAttackSourceList(DDoSAttackSourceRecord [] AttackSourceList) {
        this.AttackSourceList = AttackSourceList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Total", this.Total);
        this.setParamArrayObj(map, prefix + "AttackSourceList.", this.AttackSourceList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/dayu/v20180709/models/DescribeDDoSAttackSourceResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dayu.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDDoSAttackSourceResponse extends AbstractModel{

    /**
    * 总攻击源条数
    */
    @SerializedName("Total")
    @Expose
    private Long Total;

    /**
    * 攻击源列表
    */
    @SerializedName("AttackSourceList")
    @Expose
    private DDoSAttackSourceRecord [] AttackSourceList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 总攻击源条数 
     * @return Total 总攻击源条数
     */
    public Long getTotal() {
        return this.Total;
    }

    /**
     * Set 总攻击源条数
     * @param Total 总攻击源条数
     */
    public void setTotal(Long Total) {
        this.Total = Total;
    }

    /**
     * Get 攻击源列表 
     * @return AttackSourceList 攻击源列表
     */
    public DDoSAttackSourceRecord [] getAttackSourceList() {
        return this.AttackSourceList;
    }

    /**
     * Set 攻击源列表
     * @param AttackSourceList 攻击源列表
     */
    public void setAttackSourceList(DDoSAttackSourceRecord [] AttackSourceList) {
        this.AttackSourceList = AttackSourceList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeDDoSAttackSourceResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeDDoSAttackSourceResponse(DescribeDDoSAttackSourceResponse source) {
        if (source.Total != null) {
            this.Total = new Long(source.Total);
        }
        if (source.AttackSourceList != null) {
            this.AttackSourceList = new DDoSAttackSourceRecord[source.AttackSourceList.length];
            for (int i = 0; i < source.AttackSourceList.length; i++) {
                this.AttackSourceList[i] = new DDoSAttackSourceRecord(source.AttackSourceList[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Total", this.Total);
        this.setParamArrayObj(map, prefix + "AttackSourceList.", this.AttackSourceList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
